__version__ = "0.0.6"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = u'(HEAD detached at v0.0.6)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '703ba849b5fd8faf527f5d5dcf2e5a3b34628298'
__git_head_subject__ = u'Finished Release v0.0.6'
__git_head_message__ = u''
__git_dirty_diff__ = u''
__git_commit_date__ = '2017-07-09 14:48:03'
